==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation.md <==
# AwsRoboMakerSimulation


```text
aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation
```

```text
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation')
```



| Illustration | AwsRoboMakerSimulation | AwsRoboMakerSimulationCard | AwsRoboMakerSimulationGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation.png) | ![illustration for AwsRoboMakerSimulation](../../../aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation.Local.png) | ![illustration for AwsRoboMakerSimulationCard](../../../aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulationCard.Local.png) | ![illustration for AwsRoboMakerSimulationGroup](../../../aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulationGroup.Local.png) |




## AwsRoboMakerSimulation

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerSimulation
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation')

' renders the element
AwsRoboMakerSimulation('AwsRoboMakerSimulation', 'Aws Robo Maker Simulation', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerSimulation
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation')

' renders the element
AwsRoboMakerSimulation('AwsRoboMakerSimulation', 'Aws Robo Maker Simulation', 'an optional tech label')
@enduml
```

## AwsRoboMakerSimulationCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerSimulationCard
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation')

' renders the element
AwsRoboMakerSimulationCard('AwsRoboMakerSimulationCard', 'Aws Robo Maker Simulation Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerSimulationCard
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation')

' renders the element
AwsRoboMakerSimulationCard('AwsRoboMakerSimulationCard', 'Aws Robo Maker Simulation Card', 'an optional description')
@enduml
```

## AwsRoboMakerSimulationGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerSimulationGroup
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation')

' renders the element
AwsRoboMakerSimulationGroup('AwsRoboMakerSimulationGroup', 'Aws Robo Maker Simulation Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerSimulationGroup
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation')

' renders the element
AwsRoboMakerSimulationGroup('AwsRoboMakerSimulationGroup', 'Aws Robo Maker Simulation Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation.md <==
# AwsRoboMakerSimulation


```text
aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation
```

```text
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation')
```



| Illustration | AwsRoboMakerSimulation | AwsRoboMakerSimulationCard | AwsRoboMakerSimulationGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation.png) | ![illustration for AwsRoboMakerSimulation](../../../aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation.Local.png) | ![illustration for AwsRoboMakerSimulationCard](../../../aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulationCard.Local.png) | ![illustration for AwsRoboMakerSimulationGroup](../../../aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulationGroup.Local.png) |




## AwsRoboMakerSimulation

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerSimulation
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation')

' renders the element
AwsRoboMakerSimulation('AwsRoboMakerSimulation', 'Aws Robo Maker Simulation', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerSimulation
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation')

' renders the element
AwsRoboMakerSimulation('AwsRoboMakerSimulation', 'Aws Robo Maker Simulation', 'an optional tech label')
@enduml
```

## AwsRoboMakerSimulationCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerSimulationCard
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation')

' renders the element
AwsRoboMakerSimulationCard('AwsRoboMakerSimulationCard', 'Aws Robo Maker Simulation Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerSimulationCard
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation')

' renders the element
AwsRoboMakerSimulationCard('AwsRoboMakerSimulationCard', 'Aws Robo Maker Simulation Card', 'an optional description')
@enduml
```

## AwsRoboMakerSimulationGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerSimulationGroup
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation')

' renders the element
AwsRoboMakerSimulationGroup('AwsRoboMakerSimulationGroup', 'Aws Robo Maker Simulation Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerSimulationGroup
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerSimulation')

' renders the element
AwsRoboMakerSimulationGroup('AwsRoboMakerSimulationGroup', 'Aws Robo Maker Simulation Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
